# Generated by roxygen2: do not edit by hand

S3method(`[`,sf_component_list)
S3method(`[`,sframe_analysis_results)
S3method(`[`,sframe_item_report)
S3method(`[`,sframe_reliability_report)
S3method(`sf_plan<-`,sframe)
S3method(as.data.frame,sf_choices)
S3method(as.data.frame,sframe)
S3method(as.data.frame,sframe_analysis_results)
S3method(as.data.frame,sframe_assumption_report)
S3method(as.data.frame,sframe_codebook)
S3method(as.data.frame,sframe_descriptives_report)
S3method(as.data.frame,sframe_efa_report)
S3method(as.data.frame,sframe_efa_solution)
S3method(as.data.frame,sframe_item_report)
S3method(as.data.frame,sframe_missing_data_report)
S3method(as.data.frame,sframe_quality_report)
S3method(as.data.frame,sframe_reliability_report)
S3method(as.data.frame,sframe_sample_size_plan)
S3method(as.data.frame,sframe_sensitivity)
S3method(as.data.frame,sframe_validation)
S3method(as.data.frame,sframe_validity_report)
S3method(as_sframe,sframe)
S3method(as_sframe,sframe_validation)
S3method(format,sf_branch)
S3method(format,sf_check)
S3method(format,sf_choices)
S3method(format,sf_item)
S3method(format,sf_model)
S3method(format,sf_scale)
S3method(format,sframe)
S3method(format,sframe_validation)
S3method(plot,sframe_analysis_results)
S3method(plot,sframe_descriptives_report)
S3method(plot,sframe_efa_report)
S3method(plot,sframe_efa_solution)
S3method(plot,sframe_missing_data_report)
S3method(plot,sframe_quality_report)
S3method(plot,sframe_reliability_report)
S3method(plot,sframe_sensitivity)
S3method(plot,sframe_validity_report)
S3method(print,sf_branch)
S3method(print,sf_check)
S3method(print,sf_choices)
S3method(print,sf_component_list)
S3method(print,sf_conjoint_design)
S3method(print,sf_item)
S3method(print,sf_model)
S3method(print,sf_scale)
S3method(print,sframe)
S3method(print,sframe_analysis_results)
S3method(print,sframe_assumption_report)
S3method(print,sframe_codebook)
S3method(print,sframe_efa_report)
S3method(print,sframe_efa_solution)
S3method(print,sframe_item_report)
S3method(print,sframe_quality_report)
S3method(print,sframe_reliability_report)
S3method(print,sframe_sample_size_plan)
S3method(print,sframe_sensitivity)
S3method(print,sframe_validation)
S3method(sf_apa,sframe_analysis_results)
S3method(sf_apa,sframe_assumption_report)
S3method(sf_apa,sframe_descriptives_report)
S3method(sf_apa,sframe_missing_data_report)
S3method(sf_apa,sframe_validity_report)
S3method(sf_branches,sframe)
S3method(sf_checks,sframe)
S3method(sf_choice_sets,sframe)
S3method(sf_choice_sets,sframe_codebook)
S3method(sf_flagged,sframe_quality_report)
S3method(sf_id,sf_branch)
S3method(sf_id,sf_check)
S3method(sf_id,sf_choices)
S3method(sf_id,sf_item)
S3method(sf_id,sf_model)
S3method(sf_id,sf_scale)
S3method(sf_is_valid,sframe_validation)
S3method(sf_items,sframe)
S3method(sf_items,sframe_codebook)
S3method(sf_label,sf_branch)
S3method(sf_label,sf_check)
S3method(sf_label,sf_choices)
S3method(sf_label,sf_item)
S3method(sf_label,sf_model)
S3method(sf_label,sf_scale)
S3method(sf_meta,sframe)
S3method(sf_meta,sframe_codebook)
S3method(sf_models,sframe)
S3method(sf_models,sframe_codebook)
S3method(sf_object,sframe_validation)
S3method(sf_plan,sframe)
S3method(sf_plan,sframe_codebook)
S3method(sf_problems,sframe_validation)
S3method(sf_scales,sframe)
S3method(sf_scales,sframe_codebook)
S3method(summary,sf_branch)
S3method(summary,sf_check)
S3method(summary,sf_choices)
S3method(summary,sf_item)
S3method(summary,sf_model)
S3method(summary,sf_scale)
S3method(summary,sframe)
S3method(summary,sframe_validation)
export("sf_plan<-")
export(add_model)
export(amend_sframe)
export(amendment_log)
export(as_sframe)
export(assumption_report)
export(bootstrap_ci)
export(cfa_lavaan_syntax)
export(cfa_syntax)
export(clean_text_responses)
export(codebook_report)
export(cohens_d_ci)
export(cramers_v_ci)
export(descriptives_report)
export(efa_report)
export(efa_solution)
export(efa_syntax)
export(eta_sq_ci)
export(export_google_sheet)
export(export_static_survey)
export(extract_quotes)
export(item_report)
export(launch_builder)
export(launch_builder_demo)
export(launch_dashboard)
export(launch_dashboard_demo)
export(launch_studio)
export(launch_studio_demo)
export(link_git_commit)
export(missing_data_report)
export(model_json)
export(model_report_template)
export(ngram_frequency)
export(outlier_report)
export(posthoc_report)
export(quality_report)
export(read_responses)
export(read_sframe)
export(read_sheet_responses)
export(reliability_report)
export(render_report)
export(render_results)
export(render_survey)
export(run_analysis_plan)
export(sample_size_plan)
export(score_scales)
export(sem_lavaan_syntax)
export(seminr_syntax)
export(sensitivity_analysis)
export(sf_apa)
export(sf_branch)
export(sf_branches)
export(sf_check)
export(sf_checks)
export(sf_choice_sets)
export(sf_choices)
export(sf_conjoint_design)
export(sf_construct)
export(sf_covariance)
export(sf_flagged)
export(sf_id)
export(sf_indirect)
export(sf_instrument)
export(sf_is_valid)
export(sf_item)
export(sf_items)
export(sf_label)
export(sf_meta)
export(sf_model)
export(sf_models)
export(sf_object)
export(sf_path)
export(sf_plan)
export(sf_problems)
export(sf_scale)
export(sf_scales)
export(sframe_aggregate_judgements)
export(sframe_assemble_pairwise)
export(sframe_builder_empty_state)
export(sframe_builder_state_from_instrument)
export(sframe_builder_validate_draft)
export(sframe_codebook_items_display)
export(sframe_collected_weights)
export(sframe_decision_options)
export(sframe_demo_data)
export(sframe_draw_likert_diverging)
export(sframe_draw_mosaic)
export(sframe_input_types_demo_data)
export(sframe_likert_scale_groups)
export(sframe_plot_cooccurrence)
export(sframe_plot_cooccurrence_network)
export(sframe_plot_correlation_matrix)
export(sframe_plot_decision_ranking)
export(sframe_plot_dematel_influence)
export(sframe_plot_descriptives)
export(sframe_plot_efa_loadings)
export(sframe_plot_efa_scree)
export(sframe_plot_group_comparison)
export(sframe_plot_item_chart)
export(sframe_plot_likert_matrix)
export(sframe_plot_likert_scale)
export(sframe_plot_missingness)
export(sframe_plot_ngram_frequency)
export(sframe_plot_paired_comparison)
export(sframe_plot_quality)
export(sframe_plot_regression_diagnostics)
export(sframe_plot_reliability)
export(sframe_plot_scale_chart)
export(sframe_plot_sentiment)
export(sframe_plot_term_frequency)
export(sframe_plot_topics)
export(sframe_plot_validity)
export(sframe_plot_variable_distribution)
export(sframe_rated_matrix)
export(survey_module_server)
export(survey_module_ui)
export(term_context)
export(term_frequency)
export(theme_surveyframe)
export(validate_model)
export(validate_sframe)
export(validity_report)
export(write_sframe)
importFrom(jsonlite,
  fromJSON,
  toJSON
)
importFrom(openssl,sha256)
importFrom(rlang,
  "%||%",
  .data,
  abort,
  arg_match,
  check_installed,
  warn
)
importFrom(stats,
  complete.cases,
  cor,
  density,
  sd,
  var
)
importFrom(utils,capture.output)
