% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/model_layer.R
\name{sf_path}
\alias{sf_path}
\title{Define a structural path between constructs}
\usage{
sf_path(from, to, label = NULL)
}
\arguments{
\item{from}{Source construct ID.}

\item{to}{Target construct ID.}

\item{label}{Optional lavaan label for the path.}
}
\value{
An object of class \code{sf_path}.
}
\description{
Define a structural path between constructs
}
