% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditions.R
\name{sframe_warn_missing}
\alias{sframe_warn_missing}
\title{Warn about missing data}
\usage{
sframe_warn_missing(message, item_id = NULL, rate = NULL, ...)
}
\arguments{
\item{message}{Character. The warning message.}

\item{item_id}{Character or NULL. The item ID with missing data.}

\item{rate}{Numeric or NULL. The observed missing rate.}

\item{...}{Additional named fields passed to \code{rlang::warn()}.}
}
\description{
Warn about missing data
}
\keyword{internal}
