% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/demo_helpers.R
\name{sframe_demo_data}
\alias{sframe_demo_data}
\title{Load bundled surveyframe demo data}
\usage{
sframe_demo_data()
}
\value{
A list with \code{instrument}, \code{responses}, \code{instrument_path}, and
\code{responses_path}.
}
\description{
Loads the bundled tourism-services \code{.sframe} instrument and simulated
response dataset used in package examples and statistical workflow demos.
}
