% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditions.R
\name{sframe_abort_import}
\alias{sframe_abort_import}
\title{Abort with an import error}
\usage{
sframe_abort_import(message, path = NULL, ...)
}
\arguments{
\item{message}{Character. The error message.}

\item{path}{Character or NULL. The file path that failed to import.}

\item{...}{Additional named fields passed to \code{rlang::abort()}.}
}
\description{
Abort with an import error
}
\keyword{internal}
