% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditions.R
\name{sframe_warn_scoring}
\alias{sframe_warn_scoring}
\title{Warn about a scoring issue}
\usage{
sframe_warn_scoring(message, scale_id = NULL, ...)
}
\arguments{
\item{message}{Character. The warning message.}

\item{scale_id}{Character or NULL. The scale ID affected.}

\item{...}{Additional named fields passed to \code{rlang::warn()}.}
}
\description{
Warn about a scoring issue
}
\keyword{internal}
