% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditions.R
\name{sframe_abort_branching}
\alias{sframe_abort_branching}
\title{Abort with a branching error}
\usage{
sframe_abort_branching(message, item_id = NULL, ...)
}
\arguments{
\item{message}{Character. The error message.}

\item{item_id}{Character or NULL. The item ID involved in the broken rule.}

\item{...}{Additional named fields passed to \code{rlang::abort()}.}
}
\description{
Abort with a branching error
}
\keyword{internal}
