% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statistics_reports.R
\name{posthoc_report}
\alias{posthoc_report}
\title{Post-hoc and pairwise comparison report}
\usage{
posthoc_report(
  data,
  method = c("anova", "kruskal_wallis", "chi_square", "cochran_q"),
  outcome = NULL,
  group = NULL,
  table_vars = NULL,
  measures = NULL,
  correction = c("holm", "bonferroni", "BH")
)
}
\arguments{
\item{data}{A data.frame.}

\item{method}{Comparison family. Supports \code{"anova"}, \code{"kruskal_wallis"},
\code{"chi_square"}, and \code{"cochran_q"}.}

\item{outcome}{Outcome variable for group comparisons.}

\item{group}{Grouping variable for group comparisons.}

\item{table_vars}{Two categorical variables for chi-square residuals and
pairwise proportion tests.}

\item{measures}{Repeated binary measures for pairwise McNemar tests.}

\item{correction}{Multiple-comparison correction.}
}
\value{
An object of class \code{sframe_posthoc_report}.
}
\description{
Post-hoc and pairwise comparison report
}
