% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/model_layer.R
\name{cfa_lavaan_syntax}
\alias{cfa_lavaan_syntax}
\title{Generate lavaan CFA syntax}
\usage{
cfa_lavaan_syntax(
  instrument = NULL,
  model = NULL,
  scales = NULL,
  ordered = FALSE,
  std_lv = TRUE,
  residual_covariances = NULL,
  latent_covariances = TRUE
)
}
\arguments{
\item{instrument}{Optional \code{sframe} object used to derive constructs from
scales when \code{model} is not supplied.}

\item{model}{Optional \code{\link[=sf_model]{sf_model()}} object.}

\item{scales}{Optional scale IDs when deriving a model from an instrument.}

\item{ordered}{Logical. Whether to add an ordered-item note.}

\item{std_lv}{Logical. Whether to add a \code{std.lv = TRUE} note.}

\item{residual_covariances}{Optional list of \code{\link[=sf_covariance]{sf_covariance()}} objects for
correlated residuals.}

\item{latent_covariances}{Logical. Whether to include model-level latent
covariances supplied in \code{model}.}
}
\value{
A lavaan syntax string.
}
\description{
Generate lavaan CFA syntax
}
