% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/studio_builder.R
\name{sframe_builder_state_from_instrument}
\alias{sframe_builder_state_from_instrument}
\title{Convert an instrument into a SurveyStudio builder state}
\usage{
sframe_builder_state_from_instrument(instrument = NULL)
}
\arguments{
\item{instrument}{An \code{sframe} object or \code{NULL}.}
}
\value{
A builder state list. Component classes are restored so the state
can be edited or validated by SurveyStudio.
}
\description{
Convert an instrument into a SurveyStudio builder state
}
