% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/studio_builder.R
\name{sframe_builder_validate_draft}
\alias{sframe_builder_validate_draft}
\title{Validate a SurveyStudio draft state}
\usage{
sframe_builder_validate_draft(
  meta,
  choices = list(),
  items = list(),
  scales = list(),
  branching = list(),
  checks = list(),
  analysis_plan = list(),
  models = list()
)
}
\arguments{
\item{meta}{List of instrument metadata.}

\item{choices, items, scales, branching, checks}{Lists of draft components.}

\item{analysis_plan}{List of draft analysis-plan blocks.}

\item{models}{List of draft model specifications.}
}
\value{
A list with \code{valid}, \code{problems}, and \code{instrument}.
}
\description{
Validate a SurveyStudio draft state
}
