% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/conditions.R
\name{sframe_warn_quality}
\alias{sframe_warn_quality}
\title{Warn about a data quality issue}
\usage{
sframe_warn_quality(message, respondent_ids = NULL, ...)
}
\arguments{
\item{message}{Character. The warning message.}

\item{respondent_ids}{Character vector or NULL. IDs of affected respondents.}

\item{...}{Additional named fields passed to \code{rlang::warn()}.}
}
\description{
Warn about a data quality issue
}
\keyword{internal}
